@@ -9,10 +9,14 @@ from __future__ import print_function, division, absolute_import
 
 import os
 import sys
+import stat
+import logging
 import getpass
 import platform
 import subprocess
 
+LOGGER = logging.getLogger('tpDcc-libs-python')
+
 
 class Platforms(object):
     Windows = 'Windows'
@@ -51,7 +55,14 @@ def get_platform():
     return pl
 
 
-def get_home_directory(platform):
+def get_home_directory(platform=None):
+    """
+    Returns home folder in a platform independent way
+    :param platform: str
+    :return: str
+    """
+
+    platform = platform or get_platform()
     if platform == Platforms.Windows:
         os.environ['TMPDIR'] = os.getenv('TEMP')
         os.environ['HOME'] = os.getenv('HOMEPATH')
@@ -113,12 +124,35 @@ def get_permission(filepath):
     if os.access(filepath, os.R_OK | os.W_OK | os.X_OK):
         return True
 
+    if filepath.endswith('.pyc'):
+        return False
+
+    permission = False
     try:
-        os.chmod(filepath, 0o775)
+        permission = oct(os.stat(filepath)[stat.ST_MODE])[-3:]
+    except Exception:
+        pass
+    if not permission:
+        return False
+
+    permission = int(permission)
+    if permission < 775:
+        try:
+            os.chmod(filepath, 0o777)
+        except Exception:
+            LOGGER.warning('Was not possible to gran permission on: "{}"'.format(filepath))
+            return False
         return True
+    if permission >= 775:
+        return True
+
+    try:
+        os.chmod(filepath, 0o777)
     except Exception:
         return False
 
+    return True
+
 
 def init_env_var(name):
     """
